@@ -36,6 +36,10 @@ hidden_imports = [
     "ics.structures.stop_dhcp_server_command",
     "ics.structures.extended_response_generic",
     "ics.structures.get_supported_features_response",
+    "ics.structures.version_report",
+    "ics.structures.get_component_versions",
+    "ics.structures.get_component_versions_response",
+    "ics.structures.software_update_command",
     "ics.structures.s_ext_sub_cmd_hdr",
     "ics.structures.timestamp_",
     "ics.structures.port_identity",
@@ -101,6 +105,7 @@ hidden_imports = [
     "ics.structures.s_jupiter_ptp_params_s",
     "ics.structures.srad_jupiter_switch_settings",
     "ics.structures.srad_jupiter_settings",
+    "ics.structures.fire3_linux_settings",
     "ics.structures.s_fire3_settings",
     "ics.structures.s_rad_moon_duo_settings",
     "ics.structures.s_ether_badge_settings",
