@@ -36,6 +36,10 @@ __all__ = [
     "stop_dhcp_server_command",
     "extended_response_generic",
     "get_supported_features_response",
+    "version_report",
+    "get_component_versions",
+    "get_component_versions_response",
+    "software_update_command",
     "s_ext_sub_cmd_hdr",
     "timestamp_",
     "port_identity",
@@ -101,6 +105,7 @@ __all__ = [
     "s_jupiter_ptp_params_s",
     "srad_jupiter_switch_settings",
     "srad_jupiter_settings",
+    "fire3_linux_settings",
     "s_fire3_settings",
     "s_rad_moon_duo_settings",
     "s_ether_badge_settings",
